
NameDict={
    'place_holder':'placeholder',
    'delimiters':'delimiters',
    'data_list':'whitelist',
    'suggestions_chars':'suggestionsMinChars',
    'black_list':'blacklist',
    'max_tags':'maxTags'

}